setClass ("beadData", representation (fileOrigin="character", 
	param="list", normMethod="character", detExprs="matrix"), contains="exprSet")

if(is.null(getGeneric("pairs")))
	setGeneric("pairs")

setMethod("pairs",signature(x="beadData"),function(x,...,log=TRUE){
      
upperpanel<-function(x,y,fold=2){
	points(x,y)
	abline(0,1,col="red",lty=2)
	abline(log2(fold),1,col="green",lty=2)
	abline(log2(1/fold),1,col="green",lty=2)
	}

lowerpanel<-function(x,y,cex=1.44,fold=2, breaks=c(0,200,400,600,800,1000,1200,1400,1600)){
	up<-length(which((x-y)>log2(fold)))
	down<-length(which((y-x)>log2(fold)))
	colvector<-rev(heat.colors(length(breaks)))
	rect(min(x),min(y),max(x), max(y), col=colvector[1])
	for (i in 1:length(breaks)){ 
	   if(up+down>breaks[i])col<-colvector[i]
	   }
	rect(min(x),min(y),max(x), max(y), col=col)
	ex<-par("fin")[1]*0.9
	
	text(mean(range(x)),mean(range(y)),paste("Cor =",as.character(round(cor(x,y),2)),"\n",">2 up =", 
		up, "\n",">2 down =",down),cex=ex)
	}

   if(log){
     pairs(log2(exprs(x)),upper.panel=upperpanel,lower.panel=lowerpanel,...)
      }
  else {
      pairs(exprs(x),upper.panel=upperpanel,lower.panel=lowerpanel,...)
     }
   })



##############
if(is.null(getGeneric("boxplot")))
	setGeneric("boxplot")

setMethod("boxplot",signature(x="beadData"),function(x,...){
   boxplot(log2(data.frame(exprs(x))),...)
   })

### subset for data

setMethod("[", "beadData", function(x, i, j, ..., drop=FALSE){
      newx<-x
      if(missing(j))
      j<-TRUE
      if(missing(i))
       i<-TRUE
      if(length(exprs(x))!=0)
        exprs(newx)<-exprs(x)[i,j,drop=FALSE]
      if(length(exprs(x))!=0)
        se.exprs(newx)<-se.exprs(x)[i,j,drop=FALSE]
      if   (length(exprs(x))!=0)
        newx@detExprs<-detExprs(x)[i,j,drop=FALSE]
      return(newx)
   })

###nGenes accessor   

if( is.null(getGeneric("nGenes")))
  setGeneric("nGenes", function(object)
             standardGeneric("nGenes"))

setMethod("nGenes", signature(object="beadData"),
      function(object) nrow(exprs(object)))

###DetExprs accessor   

if( is.null(getGeneric("detExprs")))
  setGeneric("detExprs", function(object)
             standardGeneric("detExprs"))

setMethod("detExprs", "beadData",
      function(object) object@detExprs)


##annotation accessor
      
if (is.null(getGeneric("annotation")))
  	setGeneric("annotation", function(object) 
	standardGeneric("annotation")) 

##annotation replacement

if(is.null(getGeneric("annotation<-")))
	setGeneric("annotation<-", function(object,value)
      standardGeneric("annotation<-"))

#####nsamples accessor

if(is.null(getGeneric("nSamples")))
	setGeneric("nSamples", function(object)
      standardGeneric("nSamples"))

setMethod("nSamples", signature(object="beadData"),
      function(object) ncol(exprs(object)))

##fileOrigin accessor

if(is.null(getGeneric("fileOrigin")))
	setGeneric("fileOrigin", function(object)
      standardGeneric("fileOrigin"))

setMethod("fileOrigin", signature(object="beadData"),
      function(object) object@fileOrigin)

##normMethod accessor

if(is.null(getGeneric("normMethod")))
	setGeneric("normMethod", function(object)
      standardGeneric("normMethod"))

setMethod("normMethod", signature(object="beadData"),
      function(object) object@normMethod)

#####param accessor

if(is.null(getGeneric("param")))
	setGeneric("param", function(object)
      standardGeneric("param"))

setMethod("param", signature(object="beadData"),
      function(object) object@param)

###signal means accessor

if( is.null(getGeneric("signalMeans")))
       setGeneric("signalMeans", function(object)
             standardGeneric("signalMeans"))

setMethod("signalMeans", signature(object="beadData"),
       function(object) {
	   means<-numeric(0)
	      for (i in 1:ncol (exprs(object))) { 
	      means <- append (means, mean (exprs(object[,i]))) 
	      }
	   return(means)
	   })

if(is.null(getGeneric("summary")))
	setGeneric("summary")

setMethod("summary",signature(object="beadData"),function (object){

      hscalls<-detectionCalls(object, 0.99)
      lscalls<-detectionCalls(object, 0.95)
      signalmeans<-signalMeans(object)

      cat(paste("Class:", class(object)[1],"\n"))
      cat(paste(paste("Samples:", paste(sampleNames(object), collapse=", ")),"\n"))
      cat(paste(paste("Genes:", paste(nGenes(object), collapse=", ")),"\n"))
      cat(paste(paste("Signal Means:", paste(round(signalmeans,2), collapse=", ")),"\n"))
      cat(paste(paste("0.95 Detection:", paste(round(lscalls,2), collapse=", ")),"\n"))
      cat(paste(paste("0.99 Detection:", paste(round(hscalls,2), collapse=", ")),"\n"))
   })
