"dotplotArrays" <-
function(
		beadData,
		beadQC, 
		qc, 
		col=NULL, 
		currentcol="black",
		meansym=4, 
		arraysym=19, 
		currentsym=19,
		meansize=1.5,
		arraysize=1.5,
		currentsize=1.5,
		savegraph="png",
		extension="_Arrays",
		width=1200,
		height=800,
		legend=TRUE,
		verbose=TRUE,...){


      if (!is.null(savegraph)){
	 outfile<-paste(annotation(beadQC),extension,".",savegraph,sep="")
	   if(savegraph=="png"){ 
	      png (outfile, width,height)
	      }
	 else if(savegraph=="jpeg"){ 
	      jpeg (outfile, width,height)
	      }
	 else if(savegraph=="bmp"){ 
	      bmp (outfile, width,height)
	      }
	 else (stop("Unrecognised file format"))
	}


      type<-qc$ArrayContent
      if(is.null(col))col<-rainbow(length(levels(type)))
      if (length (levels (type)) != length (col)){
	 col<-rainbow(length(levels(type)))
	 warning("Number of colours in dotplotarrays does not equal number of array types, default used")
	 }

      par (oma=c(0,0,2,0), mar=c(2,4,2,2))
      layout (matrix (c(rep (1:4, each=4),5,5,5), 19, 1, byrow = TRUE))

      dotplotQC (beadData, beadQC, qc, subset=c("Detection95mean","Detection95SD",
			"Detection99mean","Detection99SD","BeadSDmean","Noise"), col=col, currentcol=currentcol, 
			meansym=meansym, arraysym=arraysym, currentsym=currentsym, meansize=meansize, arraysize=arraysize, 
			currentsize=currentsize,...)

      title (paste ("Array Quality Plots for", annotation(beadQC), "-", getArrayStats(beadData,beadQC)$ArrayContent), outer=TRUE)
      dotplotQC (beadData, beadQC, qc, subset=c("SignalMean","Background","AllGenes"), col=col, 
      	currentcol=currentcol, meansym=meansym, arraysym=arraysym, currentsym=currentsym, meansize=meansize, 
      	arraysize=arraysize, currentsize=currentsize,...)
      dotplotQC (beadData, beadQC, qc, subset=c("SignalSD","HybLow","MM"), col=col, 
      	currentcol=currentcol, meansym=meansym, arraysym=arraysym, currentsym=currentsym, meansize=meansize, 
      	arraysize=arraysize, currentsize=currentsize,...)
      par (mar=c(0,4,2,2))
      dotplotQC (beadData, beadQC, qc, subset=c("HybHigh","HybMed","Biotin","HighStringency","Housekeeping","PM"), 
		col=col, currentcol=currentcol, meansym=meansym, arraysym=arraysym, currentsym=currentsym, 
		meansize=meansize, arraysize=arraysize, currentsize=currentsize,...)
     if (legend){
        par (mar=c(0,4,0,2))
        plot.new ()
      #par (mar=c(0,4,0,2))
        legend ("center",legend=c("Current Array", levels(type), paste(levels(type),"-Mean","")),
	col=c(currentcol, col,col), pch=c(currentsym, rep (c(arraysym,meansym), each=length (levels (type)))), horiz=TRUE, pt.cex=1,cex=0.7)
        }
     
      if(verbose)cat(paste("Plotted dot arrays...", "\n"))
       if (!is.null(savegraph)){
         dev.off ()
         return(outfile)
         }  
   }

