"plotSamples" <-
function(
		rbeadData,
		nbeadData, 
		beadQC, 
		savegraph="png",
		width=1200,
		height=800, 
		extension="_Samples", 
		col=NULL,
		annotation=TRUE,
		names=sampleNames(nbeadData),
		verbose=TRUE,...){ 

      if(nSamples(nbeadData)>8) {names<-1:nSamples(nbeadData)}
      if (!is.null(savegraph)){
         outfile<-paste(annotation(beadQC),extension,".",savegraph,sep="")
	   if(savegraph=="png"){ 
	      png (outfile, width,height)
	      }
	 else if(savegraph=="jpeg"){ 
	      jpeg (outfile, width,height)
	      }
	 else if(savegraph=="bmp"){ 
	      bmp (outfile, width,height)
	      }
	 else (stop("Unrecognised file format"))
	}
	   
      
      if (is.null(col)){
	   col<-rainbow (nSamples(nbeadData))
        }
      else{
	   if (length (col) != nSamples(nbeadData)){
		 warning ("Number of colours in plotsamples does not equal number of samples, default used")
		 col<-rainbow (nSamples(nbeadData))
	         } 
	}

      if (length(names)!=nSamples(nbeadData) && names[1]!=FALSE){
	   names<-sampleNames(nbeadData)
	   }
      else if (names[1]==FALSE){
	    names<-1:nSamples(nbeadData)}
      
      layout (matrix (c(1,4,6,8,10,1,4,6,8,10,2,4,6,8,10,2,5,7,9,11,3,5,7,9,11,3,5,7,9,11,
	12,13,14,15,16,12,13,14,15,16,12,13,14,15,16,12,13,14,15,16,12,13,14,15,16,12,13,14,15,16), 12, 5, byrow = TRUE))

      par (oma=c(0,0,2,0),cex.axis=0.7)

      #ssize<-7/nSamples(nbeadData)

      for (i in 1:ncol (sampleQC(beadQC))){
	   if (i==1||i==4||i==6||i==8||i==10){
		par (mar=c(0,5,1,.5))
		plot (sampleQC(beadQC)[,i], xlab="", type="l", ylab=colnames (sampleQC(beadQC))[i], col="red", axes=FALSE,...)
		points (sampleQC(beadQC)[,i] ,col=col)
		axis (2)
		box ()
	      }

	   else{
		if (i==2){
		      par (mar=c(0,5,0,.5))
		      plot (sampleQC(beadQC)[,i], xlab="", type="l", ylab=colnames (sampleQC(beadQC))[i], col="blue", axes=FALSE,...)
		      points (sampleQC(beadQC)[,i], col=col)
		      axis (2)
		      box ()
		   }

		else{
		      par (mar=c(5,5,0,.5))
		      plot (sampleQC(beadQC)[,i],xlab="", type="l", col="green", ylab=colnames (sampleQC(beadQC))[i], axes=FALSE,...)
		      points (sampleQC (beadQC)[,i], col=col)
		      axis (2)
		      box ()
		      axis (1,at=1:nSamples(nbeadData), labels=names)#, cex.axis=ssize*.9)	     
		   }
	      }
	}

     
      
      hscalls<-detectionCalls(nbeadData, 0.99)
      lscalls<-detectionCalls(nbeadData, 0.95)
      signalmeans<-signalMeans(rbeadData)
      
      nandata<-data.frame(exprs(rbeadData))
      nandata[nandata<=0]<-NaN

      v<-boxplot (log2 (nandata), col=col, xlab="Boxplot of Unnormalised Signal", axes=FALSE,...)
      axis (2)
      box ()
      axis (1,at=1:nSamples(nbeadData), labels=names)#, cex.axis=ssize*.9)

      if (annotation){
      for (i in 1:nSamples(nbeadData)) {
	 if ((v$stats[2,i]-v$stats[3,i])<.5) {
	offset<- -0.4} else {offset<- 0.4
	}
	text (i,v$stats[3,i]+offset, as.character (round (signalmeans[i])), cex=par("cex.axis"))
	} 
      }

      boxplot (log2(data.frame(exprs(nbeadData))), col=col, xlab="Boxplot of Normalised Signal", axes=FALSE,...)
      axis (2)
      box ()
      axis (1, at=1:nSamples(nbeadData), labels=names)#, cex.axis=ssize*.9)

      a<-boxplot (data.frame(detExprs(nbeadData)), col=col, xlab="Boxplot of confidence scores", axes=FALSE,...)
      axis (2)
      box ()
      axis (1, at=1:nSamples(nbeadData), labels=names)#, cex.axis=ssize*.9)

      if (annotation){
      for (i in 1:nSamples(nbeadData)) {
	 if ((a$stats[2,i]-a$stats[3,i])<.15) {
	offset<- -0.05} else {offset<- 0.05
	}
	text (i,a$stats[3,i]+offset, as.character (round (lscalls[i])), cex=par("cex.axis"))
	text (i,a$stats[3,i]+(2*offset), as.character (round(hscalls[i])), cex=par("cex.axis"))
	} 
      }

      #pc (exprs(nbeadData), col=col,labels=names,pos=1)
      multiDensity(se.exprs(nbeadData),col=col)

      clusterplot(exprs(nbeadData),labels=names)
    
      title (paste ("Sample Quality Plots for", annotation(nbeadData), "-", param(nbeadData)$ArrayContent), outer=TRUE)
      if (verbose)cat(paste("Plotted Samples...", "\n"))
      if(!is.null(savegraph)){
          dev.off()     
          return(outfile)
          }
   }

