scatterPlot<-function(
		beadData,
		xcol,
		ycol,
		manifest=NULL,
		equalline=TRUE, 
		equallinecol="red",
		equallinetype=1,
		identify=TRUE, 
		lines=2, 
		linescol="green",
		linestype=2,
		log=TRUE,
		xlab="",
		ylab="",
		highlight=TRUE,
		detection=0.99,
		highlightcol=c("red","blue","green"),
		legend=TRUE,
		...){

   values<-exprs(beadData)
	
   if(log){
      xdata<-log2(values[,xcol])
      ydata<-log2(values[,ycol])
         if (!is.null(lines)){
	   uplinesicpt<-log2(lines)
	   downlinesicpt<-log2(1/lines)
	   uplinesgrad<-downlinesgrad<-rep(1,length(lines))
	   }
      }
   else{
      xdata<-values[,xcol]
      ydata<-values[,ycol]
         if (!is.null(lines)){
	   uplinesicpt<-lines
	   downlinesicpt<-1/lines
	   uplinesgrad<-lines
	   downlinesgrad<-1/lines
	   }
      }

   if(xlab=="") xlab<-sampleNames(beadData)[xcol]
   if(ylab=="") ylab<-sampleNames(beadData)[ycol]

   plot(xdata, ydata, xlab=xlab, ylab=ylab, ...)

   if (highlight){
	points(xdata[which(detExprs(beadData)[,xcol]>detection)],ydata[which(detExprs(beadData)[,xcol]>detection)],col=highlightcol[1])
	points(xdata[which(detExprs(beadData)[,ycol]>detection)],ydata[which(detExprs(beadData)[,ycol]>detection)],col=highlightcol[2])
	points(xdata[intersect(which(detExprs(beadData)[,xcol]>detection), which(detExprs(beadData)[,ycol]>detection))],
		ydata[intersect(which(detExprs(beadData)[,xcol]>detection), which(detExprs(beadData)[,ycol]>detection))],col=highlightcol[3])
	
	if (legend){
	legend("bottomright",legend=c(paste(xlab,">",detection,sep=""),paste(ylab,">",detection,sep=""),
		paste("Both>",detection,sep="")),fill=highlightcol) 
	}
   }

   if (!is.null(highlight)){
	rows<-grep (paste(highlight,collapse="|"),geneNames(beadData))
	points(xdata[rows],ydata[rows],col=highlightcol[1])
	}
   
   if (equalline) abline(0,1,col=equallinecol,lty=equallinetype)
   if (!is.null(lines)){
	for (i in 1:length(lines)){
	   abline(uplinesicpt[i],uplinesgrad[i],col=linescol,lty=linestype)
	   abline(downlinesicpt[i],downlinesgrad[i],col=linescol,lty=linestype)
	   }
	}
	
   if (identify){
	f<-identify(xdata, ydata, labels=rep("X",nrow(values)), col="red", offset=-0.3)
	if (!is.null(manifest)){
	         dataout<-cbind( Xintlog2=round(xdata[f],2), Yintlog2=round(ydata[f],2), Ratio=round(values[f,ycol]/values[f,xcol],2), 
		detExprs(beadData)[f,c(xcol,ycol)], unique(getAnnot(row.names(values)[f],manifest,returnFields=c("Symbol","Accession","Definition"))))
		return (dataout)
	         }
                  else {
                           dataout<-cbind( Xintlog2=round(xdata[f],2), Yintlog2=round(ydata[f],2), Ratio=round(values[f,ycol]/values[f,xcol],2), 
		detExprs(beadData)[f,c(xcol,ycol)] )
		return (dataout)
                           }

	}
}
